@@ -30,11 +30,11 @@ VSGDR::TestScriptGen - Unit test script support package for SSDT unit tests, Ded
 
 =head1 VERSION
 
-Version 0.15
+Version 0.16
 
 =cut
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 
 sub databaseName {
@@ -505,8 +505,9 @@ sub CheckForResults {
 #warn Dumper $sth->{TYPE} ;        
 #warn Dumper $sth->{NUM_OF_FIELDS} ;        
             if (scalar @names) {
+                my $col=1;
                 @types = List::MoreUtils::pairwise { $a =~ m{char|binary}ism ? "$a($b)" : "$a" }  @names, @colSize ;
-                @spec  = List::MoreUtils::pairwise { "[$a]\t\t\t$b" }  @{$sth->{NAME}}, @types ;
+                @spec  = List::MoreUtils::pairwise { ( ($a eq "" ) ? "[Column_" . ${col}++ . "]" : "[$a]" ) . "\t\t\t$b" }  @{$sth->{NAME}}, @types ;
             }
 
 #warn Dumper @spec;
